@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: EphyHeaderSniffer.cpp,v 1.43 2005/02/26 22:01:48 chpe Exp $
+ * $Id: EphyHeaderSniffer.cpp,v 1.45 2005/10/15 10:02:03 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -66,6 +66,10 @@
 #include <nsIMIMEHeaderParam.h>
 #include <nsIWindowWatcher.h>
 
+#ifdef HAVE_GECKO_1_8
+#include "EphyBadCertRejector.h"
+#endif
+
 EphyHeaderSniffer::EphyHeaderSniffer (nsIWebBrowserPersist* aPersist, MozillaEmbedPersist *aEmbedPersist,
 		nsIFile* aFile, nsIURI* aURL, nsIDOMDocument* aDocument, nsIInputStream* aPostData,
 		EphyEmbedSingle *single)
@@ -101,7 +105,16 @@ EphyHeaderSniffer::~EphyHeaderSniffer()
 	}
 }
 
-NS_IMPL_ISUPPORTS2(EphyHeaderSniffer, nsIWebProgressListener, nsIAuthPrompt)
+#ifdef HAVE_GECKO_1_8
+NS_IMPL_ISUPPORTS3 (EphyHeaderSniffer,
+		    nsIWebProgressListener,
+		    nsIInterfaceRequestor,
+		    nsIAuthPrompt)
+#else
+NS_IMPL_ISUPPORTS2 (EphyHeaderSniffer,
+		    nsIWebProgressListener,
+		    nsIAuthPrompt)
+#endif
 
 NS_IMETHODIMP
 EphyHeaderSniffer::HandleContent ()
@@ -202,6 +215,36 @@ EphyHeaderSniffer::OnSecurityChange (nsIWebProgress *aWebProgress, nsIRequest *a
 	return NS_OK;
 }
 
+#ifdef HAVE_GECKO_1_8
+
+/* void getInterface (in nsIIDRef uuid, [iid_is (uuid), retval] out nsQIResult result); */
+NS_IMETHODIMP
+EphyHeaderSniffer::GetInterface(const nsIID & uuid, void * *result)
+{
+	if (uuid.Equals (NS_GET_IID (nsIBadCertListener)) &&
+	    mEmbedPersist)
+	{
+		EphyEmbedPersistFlags flags;
+
+		g_object_get (mEmbedPersist, "flags", &flags, (char *) NULL);
+
+		if (flags & EPHY_EMBED_PERSIST_NO_CERTDIALOGS)
+		{
+			EphyBadCertRejector *badCertRejector = new EphyBadCertRejector ();
+			if (!badCertRejector) return NS_ERROR_OUT_OF_MEMORY;
+
+			*result = NS_STATIC_CAST(nsIBadCertListener*, badCertRejector);
+			NS_ADDREF (badCertRejector);
+
+			return NS_OK;
+		}
+	}
+
+	return NS_ERROR_NO_INTERFACE;
+}
+
+#endif /* HAVE_GECKO_1_8 */
+
 static void
 filechooser_response_cb (GtkWidget *dialog,
 			 gint response,	
@@ -213,7 +256,7 @@ filechooser_response_cb (GtkWidget *dialog,
 
 		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 
-		if (ephy_gui_confirm_overwrite_file (dialog, filename) == FALSE)
+		if (ephy_gui_check_location_writable (dialog, filename) == FALSE)
 		{
 			g_free (filename);
 			return;
@@ -367,6 +410,7 @@ nsresult EphyHeaderSniffer::PerformSave (nsIURI* inOriginalURI)
 						GTK_FILE_CHOOSER_ACTION_SAVE,
 						key ? key : CONF_STATE_SAVE_DIR,
 						EPHY_FILE_FILTER_ALL_SUPPORTED);
+		gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
 
 		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog),
                                                    filename);
