@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyUtils.cpp,v 1.16 2005/10/06 18:43:10 chpe Exp $
+ *  $Id: EphyUtils.cpp,v 1.17 2006/01/17 13:58:19 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -30,6 +30,7 @@
 
 #include <nsIIOService.h>
 #include <nsIURI.h>
+#include <nsIFile.h>
 #include <nsIDOMWindow.h>
 #include <nsIServiceManager.h>
 #undef MOZILLA_INTERNAL_API
@@ -75,14 +76,23 @@ EphyUtils::NewURI (nsIURI **result,
 		   nsIURI *baseURI)
 {
 	nsresult rv;
-
 	nsCOMPtr<nsIIOService> ioService;
 	rv = EphyUtils::GetIOService (getter_AddRefs (ioService));
 	NS_ENSURE_SUCCESS (rv, rv);
 
-	rv = ioService->NewURI (spec, charset, baseURI, result);
+	return ioService->NewURI (spec, charset, baseURI, result);
+}
 
-	return rv;
+nsresult
+EphyUtils::NewFileURI (nsIURI **result,
+		       nsIFile *spec)
+{
+	nsresult rv;
+	nsCOMPtr<nsIIOService> ioService;
+	rv = EphyUtils::GetIOService (getter_AddRefs (ioService));
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	return ioService->NewFileURI (spec, result);
 }
 
 GtkWidget *
@@ -244,7 +254,7 @@ EphyUtils::CollatePrintSettings (EmbedPrintInfo *info,
 		const char *temp_dir;
 		
 		temp_dir = ephy_file_tmp_dir ();
-		base = g_build_filename (temp_dir, "printXXXXXX", NULL);
+		base = g_build_filename (temp_dir, "printXXXXXX", (char *) NULL);
 		info->tempfile = ephy_file_tmp_filename (base, "ps");
 		g_free (base);
 		
