@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyUtils.h,v 1.9 2005/07/23 21:31:19 chpe Exp $
+ *  $Id: EphyUtils.h,v 1.10 2006/01/17 13:58:20 chpe Exp $
  */
 
 #ifndef EPHY_UTILS_H
@@ -30,6 +30,7 @@ class nsIDOMWindow;
 class nsIIOService;
 class nsIPrintSettings;
 class nsIURI;
+class nsIFile;
 struct _EmbedPrintInfo;
 
 namespace EphyUtils
@@ -46,6 +47,9 @@ namespace EphyUtils
 						 const char *charset = nsnull,
 						 nsIURI *baseURI = nsnull);
 
+	nsresult	NewFileURI		(nsIURI **result,
+						 nsIFile *spec);
+
 	GtkWidget      *FindEmbed		(nsIDOMWindow *aDOMWindow);
 
 	GtkWidget      *FindGtkParent		(nsIDOMWindow *aDOMWindow);
