@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.26 2005/12/05 20:23:49 chpe Exp $
+ *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.27 2006/02/02 22:25:18 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -25,6 +25,7 @@
 #include "config.h"
 
 #include "EphyUtils.h"
+#include "AutoJSContextStack.h"
 
 #include <nsIDOMWindow.h>
 #include <nsIServiceManager.h>
@@ -145,6 +146,11 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	char *msg, *markup_text;
 	PRUint32 i;
 
+	nsresult rv;
+	AutoJSContextStack stack;
+	rv = stack.Init ();
+	if (NS_FAILED (rv)) return rv;
+
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
 	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
@@ -155,7 +161,7 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 					      GTK_RESPONSE_CANCEL,
 					      _("_Select Certificate"),
 					      GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -234,7 +240,7 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
         gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
         gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer,
                                         "text", 0,
-                                        NULL);
+                                        (char *) NULL);
 
 	gtk_widget_show (combo);
 	gtk_box_pack_start (GTK_BOX (vbox), combo, FALSE, TRUE, 0);
