@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.25 2006/02/02 22:25:18 chpe Exp $
+ *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.26 2006/03/02 19:41:23 chpe Exp $
  */
 
 /*
@@ -80,8 +80,8 @@ GtkNSSKeyPairDialogs::~GtkNSSKeyPairDialogs ()
 	LOG ("GtkNSSKeyPairDialogs dtor (%p)", this);
 }
 
-NS_IMPL_ISUPPORTS1 (GtkNSSKeyPairDialogs, 
-		    nsIGeneratingKeypairInfoDialogs)
+NS_IMPL_THREADSAFE_ISUPPORTS1 (GtkNSSKeyPairDialogs,
+			       nsIGeneratingKeypairInfoDialogs)
 
 #ifdef HAVE_GECKO_1_8
 
@@ -207,7 +207,7 @@ GtkNSSKeyPairDialogs::DisplayGeneratingKeypairInfo (nsIInterfaceRequestor *ctx,
 	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
 	dialog = gtk_dialog_new_with_buttons ("", gparent,
-					      GTK_DIALOG_DESTROY_WITH_PARENT, NULL);
+					      GTK_DIALOG_DESTROY_WITH_PARENT, (char *) NULL);
 
 	if (gparent)
 	{
