@@ -38,7 +38,7 @@
  *
  *  Copyright (C) 2005 Christian Persch
  *
- *  $Id: GtkNSSSecurityWarningDialogs.cpp,v 1.12 2006/02/20 19:23:20 chpe Exp $
+ *  $Id: GtkNSSSecurityWarningDialogs.cpp,v 1.13 2006/03/02 19:41:23 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -64,9 +64,7 @@
 #include <gtk/gtkvbox.h>
 #include <gtk/gtklabel.h>
 
-/* FIXME why threadsafe? it's proxied by nsSecureBrowserImpl */
-/* NS_IMPL_THREADSAFE_ISUPPORTS1 (GtkNSSSecurityWarningDialogs, nsISecurityWarningDialogs) */
-NS_IMPL_ISUPPORTS1 (GtkNSSSecurityWarningDialogs, nsISecurityWarningDialogs)
+NS_IMPL_THREADSAFE_ISUPPORTS1 (GtkNSSSecurityWarningDialogs, nsISecurityWarningDialogs)
 
 #define ENTER_SITE_PREF      "security.warn_entering_secure"
 #define WEAK_SITE_PREF       "security.warn_entering_weak"
@@ -215,7 +213,7 @@ GtkNSSSecurityWarningDialogs::DoDialog (nsIInterfaceRequestor *aContext,
 	PRBool showOnce = PR_FALSE;
 	if (!show && prefBranch && aPrefName)
 	{
-		showOncePref = g_strconcat (aPrefName, ".show_once", NULL);
+		showOncePref = g_strconcat (aPrefName, ".show_once", (char *) NULL);
 		rv = prefBranch->GetBoolPref (showOncePref, &showOnce);
 		if (NS_FAILED (rv)) showOnce = PR_FALSE;
 	}
