@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.77 2005/10/29 21:38:35 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.78.2.2 2006/04/03 11:58:15 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -554,13 +554,16 @@ MozDownload::OnProgressChange (nsIWebProgress *aWebProgress,
 
 	mLastUpdate = now;
 
-	if (aMaxTotalProgress == -1)
+	if (aMaxTotalProgress <= 0)
 	{
             mPercentComplete = -1;
 	}
 	else
 	{
-	        mPercentComplete = (PRInt32)(((float)aCurTotalProgress / (float)aMaxTotalProgress) * 100.0 + 0.5);
+		/* Make sure not to round up, so we don't display 100% unless
+		 * it's really finished! 
+		 */
+	        mPercentComplete = (PRInt32)(((float)aCurTotalProgress / (float)aMaxTotalProgress) * 100.0);
 	}
 
 	mTotalProgress = aMaxTotalProgress;
@@ -604,7 +607,7 @@ MozDownload::GetInterface(const nsIID & uuid, void * *result)
 	{
 		EphyEmbedPersistFlags flags;
 
-		g_object_get (mEmbedPersist, "flags", &flags, NULL);
+		g_object_get (mEmbedPersist, "flags", &flags, (char *) NULL);
 
 		if (flags & EPHY_EMBED_PERSIST_NO_CERTDIALOGS)
 		{
@@ -777,14 +780,14 @@ GetFilePath (const char *filename)
 
 	download_dir = ephy_file_get_downloads_dir ();
 
-	if (ephy_ensure_dir_exists (download_dir))
+	if (ephy_ensure_dir_exists (download_dir, NULL))
 	{
-		path = g_build_filename (download_dir, filename, NULL);
+		path = g_build_filename (download_dir, filename, (char *) NULL);
 	}
 	else
 	{
 		home_dir = g_get_home_dir ();
-		path = g_build_filename (home_dir ? home_dir : "/", filename, NULL);
+		path = g_build_filename (home_dir ? home_dir : "/", filename, (char *) NULL);
 	}
 	g_free (download_dir);
 	
